==> widget-embedder-3.10.0.tgz: package/react/Widget.js <==
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";

function _createSuper(Derived) {
  function isNativeReflectConstruct() {
    if (typeof Reflect === "undefined" || !Reflect.construct) return false;
    if (Reflect.construct.sham) return false;
    if (typeof Proxy === "function") return true;

    try {
      Date.prototype.toString.call(Reflect.construct(Date, [], function () {}));
      return true;
    } catch (e) {
      return false;
    }
  }

  return function () {
    var Super = _getPrototypeOf(Derived),
        result;

    if (isNativeReflectConstruct()) {
      var NewTarget = _getPrototypeOf(this).constructor;

      result = Reflect.construct(Super, arguments, NewTarget);
    } else {
      result = Super.apply(this, arguments);
    }

    return _possibleConstructorReturn(this, result);
  };
}

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import Context from '@s-ui/react-context';
import { Provider as ProviderLegacy } from '@s-ui/react-domain-connector';

var Widget = /*#__PURE__*/function (_Component) {
  _inheritsLoose(Widget, _Component);

  var _super = _createSuper(Widget);

  function Widget() {
    return _Component.apply(this, arguments) || this;
  }

  var _proto = Widget.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this$props = this.props,
        selector = _this$props.node,
        children = _this$props.children,
        i18n = _this$props.i18n,
        domain = _this$props.domain,
        isVisible = _this$props.isVisible;
    var node = document.querySelector(selector);

    if (!node) {
      return console.warn("[Widget] unable find the selector " + selector); // eslint-disable-line
    }

    isVisible && ReactDOM.render( /*#__PURE__*/React.createElement(Context.Provider, {
      value: {
        i18n: i18n,
        domain: domain
      }
    }, /*#__PURE__*/React.createElement(ProviderLegacy, {
      i18n: i18n,
      domain: domain
    }, children)), node);
  };

  _proto.render = function render() {
    return null;
  };

  return Widget;
}(Component);

Widget.defaultProps = {
  isVisible: true
};
export { Widget as default };

==> widget-embedder-3.12.0.tgz: package/react/Widget.js <==
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import ReactDOM from 'react-dom';
import Context from '@s-ui/react-context';
import { Provider as ProviderLegacy } from '@s-ui/react-domain-connector';

var Widget = /*#__PURE__*/function (_Component) {
  _inheritsLoose(Widget, _Component);

  function Widget() {
    return _Component.apply(this, arguments) || this;
  }

  var _proto = Widget.prototype;

  _proto.componentDidMount = function componentDidMount() {
    var _this$props = this.props,
        selector = _this$props.node,
        children = _this$props.children,
        i18n = _this$props.i18n,
        domain = _this$props.domain,
        isVisible = _this$props.isVisible,
        browser = _this$props.browser;
    var node = document.querySelector(selector);

    if (!node) {
      return console.warn("[Widget] unable find the selector " + selector); // eslint-disable-line
    }

    isVisible && ReactDOM.render( /*#__PURE__*/React.createElement(Context.Provider, {
      value: {
        i18n: i18n,
        domain: domain,
        browser: browser
      }
    }, /*#__PURE__*/React.createElement(ProviderLegacy, {
      i18n: i18n,
      domain: domain,
      browser: browser
    }, children)), node);
  };

  _proto.render = function render() {
    return null;
  };

  return Widget;
}(Component);

Widget.defaultProps = {
  isVisible: true
};
export { Widget as default };
